import { CfnWorkGroup } from 'aws-cdk-lib/aws-athena';
import { IPrincipal, IRole } from 'aws-cdk-lib/aws-iam';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { IBucket } from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
import { AthenaWorkgroupProps } from './athena-workgroup-props';
import { TrackedConstruct } from '../../../utils';
/**
 * An Amazon Athena Workgroup configured with default result bucket.
 *
 * @example
 * new dsf.consumption.AthenaWorkGroup(this, 'AthenaWorkGroupDefault', {
 *    name: 'athena-default',
 *    resultLocationPrefix: 'athena-default-results/'
 *  })
 */
export declare class AthenaWorkGroup extends TrackedConstruct {
    /**
     * Athena Workgroup that is created.
     */
    readonly workGroup: CfnWorkGroup;
    /**
     * WorkGroup name with the randomized suffix.
     */
    readonly workGroupName: string;
    /**
     * S3 Bucket used for query results.
     */
    readonly resultBucket: IBucket;
    /**
     * KMS Key to encrypt the query results.
     */
    readonly resultsEncryptionKey: IKey;
    /**
     * Role used to access user resources in an Athena for Apache Spark session.
     */
    readonly executionRole?: IRole;
    /**
     * Constructor properties for internal use.
     */
    private athenaWorkGroupProps;
    constructor(scope: Construct, id: string, props: AthenaWorkgroupProps);
    /**
     * Grants running queries access to Principal.
     * @param principal Principal to attach query access to Athena Workgroup.
     */
    grantRunQueries(principal: IPrincipal): void;
}
