import { ICertificateAuthority } from 'aws-cdk-lib/aws-acmpca';
import { InstanceType } from 'aws-cdk-lib/aws-ec2';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { ILogGroup } from 'aws-cdk-lib/aws-logs';
import { IBucket } from 'aws-cdk-lib/aws-s3';
/**
 * Kafka cluster version
 */
export declare class KafkaVersion {
    readonly version: string;
    /**
     * **Deprecated by Amazon MSK. You can't create a Kafka cluster with a deprecated version.**
     *
     * Kafka version 1.1.1
     *
     * @deprecated use the latest runtime instead
     */
    static readonly V1_1_1: KafkaVersion;
    /**
     * Kafka version 2.2.1
     */
    static readonly V2_2_1: KafkaVersion;
    /**
     * Kafka version 2.3.1
     */
    static readonly V2_3_1: KafkaVersion;
    /**
     * Kafka version 2.4.1
     */
    static readonly V2_4_1_1: KafkaVersion;
    /**
     * Kafka version 2.5.1
     */
    static readonly V2_5_1: KafkaVersion;
    /**
     * Kafka version 2.6.0
     */
    static readonly V2_6_0: KafkaVersion;
    /**
     * Kafka version 2.6.1
     */
    static readonly V2_6_1: KafkaVersion;
    /**
     * Kafka version 2.6.2
     */
    static readonly V2_6_2: KafkaVersion;
    /**
     * Kafka version 2.6.3
     */
    static readonly V2_6_3: KafkaVersion;
    /**
     * Kafka version 2.7.0
     */
    static readonly V2_7_0: KafkaVersion;
    /**
     * Kafka version 2.7.1
     */
    static readonly V2_7_1: KafkaVersion;
    /**
     * Kafka version 2.7.2
     */
    static readonly V2_7_2: KafkaVersion;
    /**
     * Kafka version 2.8.0
     */
    static readonly V2_8_0: KafkaVersion;
    /**
     * Kafka version 2.8.1
     */
    static readonly V2_8_1: KafkaVersion;
    /**
     * AWS MSK Kafka version 2.8.2.tiered
     */
    static readonly V2_8_2_TIERED: KafkaVersion;
    /**
     * Kafka version 3.1.1
     */
    static readonly V3_1_1: KafkaVersion;
    /**
     * Kafka version 3.2.0
     */
    static readonly V3_2_0: KafkaVersion;
    /**
     * Kafka version 3.3.1
     */
    static readonly V3_3_1: KafkaVersion;
    /**
     * Kafka version 3.3.2
     */
    static readonly V3_3_2: KafkaVersion;
    /**
     * Kafka version 3.4.0
     */
    static readonly V3_4_0: KafkaVersion;
    /**
     * Kafka version 3.5.1
     */
    static readonly V3_5_1: KafkaVersion;
    /**
     * Kafka version 3.6.0
     */
    static readonly V3_6_0: KafkaVersion;
    /**
     * Kafka version 3.7.x
     */
    static readonly V3_7_X: KafkaVersion;
    /**
     * Kafka version 3.7.x.kraft
     */
    static readonly V3_7_X_KRAFT: KafkaVersion;
    /**
     * Custom cluster version
     * @param version custom version number
     */
    static of(version: string): KafkaVersion;
    /**
     *
     * @param version cluster version number
     */
    private constructor();
}
/**
 * Kafka cluster version
 */
export declare class MskBrokerInstanceType {
    readonly instance: InstanceType;
    /**
     * Borker instance type kafka.t3.small
     */
    static readonly KAFKA_T3_SMALL: MskBrokerInstanceType;
    /**
     * Borker instance type kafka.m5.large
     */
    static readonly KAFKA_M5_LARGE: MskBrokerInstanceType;
    /**
     * Borker instance type kafka.m5.xlarge
     */
    static readonly KAFKA_M5_XLARGE: MskBrokerInstanceType;
    /**
     * Borker instance type kafka.m5.2xlarge
     */
    static readonly KAFKA_M5_2XLARGE: MskBrokerInstanceType;
    /**
     * Borker instance type kafka.m5.4xlarge
     */
    static readonly KAFKA_M5_4XLARGE: MskBrokerInstanceType;
    /**
     * Borker instance type kafka.m5.8xlarge
     */
    static readonly KAFKA_M5_8XLARGE: MskBrokerInstanceType;
    /**
     * Borker instance type kafka.m5.12xlarge
     */
    static readonly KAFKA_M5_12XLARGE: MskBrokerInstanceType;
    /**
     * Borker instance type kafka.m5.16xlarge
     */
    static readonly KAFKA_M5_16XLARGE: MskBrokerInstanceType;
    /**
     * Borker instance type kafka.m5.24xlarge
     */
    static readonly KAFKA_M5_24XLARGE: MskBrokerInstanceType;
    /**
     * Borker instance type kafka.m7g.large
     */
    static readonly KAFKA_M7G_LARGE: MskBrokerInstanceType;
    /**
     * Borker instance type kafka.m7g.xlarge
     */
    static readonly KAFKA_M7G_XLARGE: MskBrokerInstanceType;
    /**
     * Borker instance type kafka.m7g.2xlarge
     */
    static readonly KAFKA_M7G_2XLARGE: MskBrokerInstanceType;
    /**
     * Borker instance type kafka.m7g.4xlarge
     */
    static readonly KAFKA_M7G_4XLARGE: MskBrokerInstanceType;
    /**
     * Borker instance type kafka.m7g.8xlarge
     */
    static readonly KAFKA_M7G_8XLARGE: MskBrokerInstanceType;
    /**
     * Borker instance type kafka.m7g.12xlarge
     */
    static readonly KAFKA_M7G_12XLARGE: MskBrokerInstanceType;
    /**
     * Borker instance type kafka.m7g.16xlarge
     */
    static readonly KAFKA_M7G_16XLARGE: MskBrokerInstanceType;
    /**
     * Borker instance type kafka.m7g.24xlarge
     */
    static readonly KAFKA_M7G_24XLARGE: MskBrokerInstanceType;
    /**
     * Custom cluster version
     * @param version custom version number
     */
    private static of;
    /**
     *
     * @param version cluster version number
     */
    private constructor();
}
/**
 * EBS volume information.
 */
export interface EbsStorageInfo {
    /**
     * The size in GiB of the EBS volume for the data drive on each broker node.
     * @default 1000
     */
    readonly volumeSize?: number;
    /**
     * The AWS KMS key for encrypting data at rest.
     * @default Uses AWS managed CMK (aws/kafka)
     */
    readonly encryptionKey?: IKey;
}
/**
 * The storage mode for the cluster brokers.
 */
export declare enum StorageMode {
    /**
     * Local storage mode utilizes network attached EBS storage.
     */
    LOCAL = "LOCAL",
    /**
     * Tiered storage mode utilizes EBS storage and Tiered storage.
     */
    TIERED = "TIERED"
}
/**
 * The Amazon MSK configuration to use for the cluster.
 * Note: There is currently no Cloudformation Resource to create a Configuration
 */
export interface ClusterConfigurationInfo {
    /**
     * The Amazon Resource Name (ARN) of the MSK configuration to use.
     * For example, arn:aws:kafka:us-east-1:123456789012:configuration/example-configuration-name/abcdabcd-1234-abcd-1234-abcd123e8e8e-1.
     */
    readonly arn: string;
    /**
     * The revision of the Amazon MSK configuration to use.
     */
    readonly revision: number;
}
/**
 * The level of monitoring for the MSK cluster
 * @see https://docs.aws.amazon.com/msk/latest/developerguide/monitoring.html#metrics-details
 */
export declare enum ClusterMonitoringLevel {
    /**
     * Default metrics are the essential metrics to monitor.
     */
    DEFAULT = "DEFAULT",
    /**
     * Per Broker metrics give you metrics at the broker level.
     */
    PER_BROKER = "PER_BROKER",
    /**
     * Per Topic Per Broker metrics help you understand volume at the topic level.
     */
    PER_TOPIC_PER_BROKER = "PER_TOPIC_PER_BROKER",
    /**
     * Per Topic Per Partition metrics help you understand consumer group lag at the topic partition level.
     */
    PER_TOPIC_PER_PARTITION = "PER_TOPIC_PER_PARTITION"
}
/**
 * Monitoring Configuration
 */
export interface MonitoringConfiguration {
    /**
     * Specifies the level of monitoring for the MSK cluster.
     * @default DEFAULT
     */
    readonly clusterMonitoringLevel?: ClusterMonitoringLevel;
    /**
     * Indicates whether you want to enable or disable the JMX Exporter.
     * @default false
     */
    readonly enablePrometheusJmxExporter?: boolean;
    /**
     * Indicates whether you want to enable or disable the Prometheus Node Exporter.
     * You can use the Prometheus Node Exporter to get CPU and disk metrics for the broker nodes.
     * @default false
     */
    readonly enablePrometheusNodeExporter?: boolean;
}
/**
 * Configuration details related to broker logs.
 */
export interface BrokerLogging {
    /**
     * The Kinesis Data Firehose delivery stream that is the destination for broker logs.
     * @default - disabled
     */
    readonly firehoseDeliveryStreamName?: string;
    /**
     * The CloudWatch Logs group that is the destination for broker logs.
     * @default - disabled
     */
    readonly cloudwatchLogGroup?: ILogGroup;
    /**
     * Details of the Amazon S3 destination for broker logs.
     * @default - disabled
     */
    readonly s3?: S3LoggingConfiguration;
}
/**
 * Details of the Amazon S3 destination for broker logs.
 */
export interface S3LoggingConfiguration {
    /**
     * The S3 bucket that is the destination for broker logs.
     */
    readonly bucket: IBucket;
    /**
     * The S3 prefix that is the destination for broker logs.
     * @default - no prefix
     */
    readonly prefix?: string;
}
/**
 * SASL authentication properties
 */
export interface SaslAuthProps {
    /**
     * Enable IAM access control.
     * @default - false
     */
    readonly iam?: boolean;
}
/**
 * TLS authentication properties
 */
export interface TlsAuthProps {
    /**
     * List of ACM Certificate Authorities to enable TLS authentication.
     * @default - none
     */
    readonly certificateAuthorities?: ICertificateAuthority[];
}
/**
 * SASL + TLS authentication properties
 */
export interface SaslTlsAuthProps extends SaslAuthProps, TlsAuthProps {
}
/**
 * Configuration properties for client authentication.
 */
export declare class ClientAuthentication {
    readonly saslProps?: SaslAuthProps | undefined;
    readonly tlsProps?: TlsAuthProps | undefined;
    /**
     * SASL authentication
     */
    static sasl(props: SaslAuthProps): ClientAuthentication;
    /**
     * TLS authentication
     */
    static tls(props: TlsAuthProps): ClientAuthentication;
    /**
     * SASL + TLS authentication
     */
    static saslTls(saslTlsProps: SaslTlsAuthProps): ClientAuthentication;
    /**
     * @param saslProps - properties for SASL authentication
     * @param tlsProps - properties for TLS authentication
     */
    private constructor();
}
/**
 * TLS authentication properties
 */
export interface VpcTlsAuthProps {
    /**
     * enable TLS authentication.
     * @default - none
     */
    readonly tls?: boolean;
}
/**
 * SASL + TLS authentication properties
 */
export interface SaslVpcTlsAuthProps extends SaslAuthProps, VpcTlsAuthProps {
}
/**
 * Configuration properties for VPC client authentication.
 */
export declare class VpcClientAuthentication {
    readonly saslProps?: SaslAuthProps | undefined;
    readonly tlsProps?: VpcTlsAuthProps | undefined;
    /**
     * SASL authentication
     */
    static sasl(props: SaslAuthProps): VpcClientAuthentication;
    /**
     * TLS authentication
     */
    static tls(props: VpcTlsAuthProps): VpcClientAuthentication;
    /**
     * SASL + TLS authentication
     */
    static saslTls(saslTlsProps: SaslVpcTlsAuthProps): VpcClientAuthentication;
    /**
     * @param saslProps - properties for SASL authentication
     * @param tlsProps - properties for TLS authentication
     */
    private constructor();
}
export declare enum Authentication {
    IAM = "iam",
    MTLS = "mTLS"
}
export declare enum AclResourceTypes {
    UNKNOWN = 0,
    ANY = 1,
    TOPIC = 2,
    GROUP = 3,
    CLUSTER = 4,
    TRANSACTIONAL_ID = 5,
    DELEGATION_TOKEN = 6
}
export declare enum AclPermissionTypes {
    UNKNOWN = 0,
    ANY = 1,
    DENY = 2,
    ALLOW = 3
}
export declare enum AclOperationTypes {
    UNKNOWN = 0,
    ANY = 1,
    ALL = 2,
    READ = 3,
    WRITE = 4,
    CREATE = 5,
    DELETE = 6,
    ALTER = 7,
    DESCRIBE = 8,
    CLUSTER_ACTION = 9,
    DESCRIBE_CONFIGS = 10,
    ALTER_CONFIGS = 11,
    IDEMPOTENT_WRITE = 12
}
export declare enum ResourcePatternTypes {
    UNKNOWN = 0,
    ANY = 1,
    MATCH = 2,
    LITERAL = 3,
    PREFIXED = 4
}
export declare const MSK_DEFAULT_VERSION: KafkaVersion;
/**
 * Kakfa ACL
 * This is similar to the object used by `kafkajs`, for more information see this [link](https://kafka.js.org/docs/admin#create-acl)
 */
export interface Acl {
    readonly principal: string;
    readonly host: string;
    readonly operation: AclOperationTypes;
    readonly permissionType: AclPermissionTypes;
    readonly resourceType: AclResourceTypes;
    readonly resourceName: string;
    readonly resourcePatternType: ResourcePatternTypes;
}
/**
 * Properties for the `MskTopic`
 * As defined in `ITopicConfig` in [KafkaJS](https://kafka.js.org/docs/admin) SDK
 */
export interface MskTopic {
    /**
     * The name of the topic
     */
    readonly topic: string;
    /**
     * The number of partitions in the topic
     */
    readonly numPartitions: number;
    /**
     * The replication factor of the partitions. This parameter cannot be updated after the creation of the topic.
     * This parameter should not be provided for MSK Serverless.
     * @default - For MSK Serverless, the number of AZ. For MSK Provisioned, the cluster default configuration.
     */
    readonly replicationFactor?: number;
    /**
     * The topic level configurations.
     * This parameter cannot be updated after the creation of the topic.
     * @default - no configuration is used
     */
    readonly configEntries?: {
        [key: string]: string;
    }[];
}
/**
 * The CDK Custom resources uses KafkaJs.
 * This enum allow you to set the log level
 */
export declare enum KafkaClientLogLevel {
    WARN = "WARN",
    DEBUG = "DEBUG",
    INFO = "INFO",
    ERROR = "ERROR"
}
/**
 * Enum for MSK cluster types
 */
export declare enum MskClusterType {
    PROVISIONED = "PROVISIONED",
    SERVERLESS = "SERVERLESS"
}
